/**
 * @file
 * VuoRendererColors interface.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This interface description may be modified and distributed under the terms of the GNU Lesser General Public License (LGPL) version 2 or later.
 * For more information, see http://vuo.org/license.
 */

#ifndef VUORENDERERCOLORS_HH
#define VUORENDERERCOLORS_HH

#include "VuoNode.hh"

/**
 * Provides colors for rendered items in a composition.
 */
class VuoRendererColors
{
public:
	static VuoRendererColors *getSharedColors(void);
	VuoRendererColors(VuoNode::TintColor tintColor = VuoNode::TintNone, bool isSelected = false, bool isHovered = false, bool isHighlighted = false);

	QColor canvasFill(void);

	QColor nodeFill(void);
	QColor nodeFrame(void);
	QColor nodeTitle(void);
	QColor nodeClass(void);

	QColor portFill(void);
	QColor portTitlebarFill(void);
	QColor portTitle(void);

	QColor cableUpper(void);
	QColor cableMain(void);

private:
	static VuoRendererColors *sharedColors;

	VuoNode::TintColor tintColor;
	bool isSelected;
	bool isHovered;
	bool isHighlighted;

	QColor tint(QColor color, qreal amount = 1.);
	QColor lerpColor(QColor v0, QColor v1, float t);
};

#endif // VUORENDERERCOLORS_HH
